Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterTychoIndexerServer(s grpc.ServiceRegistrar, srv TychoIndexerServer)
- type BlockById
- type BlockBySeqno
- func (*BlockBySeqno) Descriptor() ([]byte, []int)deprecated
- func (x *BlockBySeqno) GetSeqno() uint32
- func (x *BlockBySeqno) GetShard() uint64
- func (x *BlockBySeqno) GetWorkchain() int32
- func (*BlockBySeqno) ProtoMessage()
- func (x *BlockBySeqno) ProtoReflect() protoreflect.Message
- func (x *BlockBySeqno) Reset()
- func (x *BlockBySeqno) String() string
- type BlockChunk
- type BlockFound
- func (*BlockFound) Descriptor() ([]byte, []int)deprecated
- func (x *BlockFound) GetFirstChunk() *BlockChunk
- func (x *BlockFound) GetMaxChunkSize() uint64
- func (x *BlockFound) GetMcStateInfo() *McStateInfo
- func (x *BlockFound) GetTotalSize() uint64
- func (*BlockFound) ProtoMessage()
- func (x *BlockFound) ProtoReflect() protoreflect.Message
- func (x *BlockFound) Reset()
- func (x *BlockFound) String() string
- type BlockId
- func (*BlockId) Descriptor() ([]byte, []int)deprecated
- func (x *BlockId) GetFileHash() []byte
- func (x *BlockId) GetRootHash() []byte
- func (x *BlockId) GetSeqno() uint32
- func (x *BlockId) GetShard() uint64
- func (x *BlockId) GetWorkchain() int32
- func (*BlockId) ProtoMessage()
- func (x *BlockId) ProtoReflect() protoreflect.Message
- func (x *BlockId) Reset()
- func (x *BlockId) String() string
- type BlockNotFound
- type BlocksRangeSkipped
- func (*BlocksRangeSkipped) Descriptor() ([]byte, []int)deprecated
- func (x *BlocksRangeSkipped) GetFrom() uint32
- func (x *BlocksRangeSkipped) GetMcStateInfo() *McStateInfo
- func (x *BlocksRangeSkipped) GetTo() uint32
- func (*BlocksRangeSkipped) ProtoMessage()
- func (x *BlocksRangeSkipped) ProtoReflect() protoreflect.Message
- func (x *BlocksRangeSkipped) Reset()
- func (x *BlocksRangeSkipped) String() string
- type GetBlockRequest
- func (*GetBlockRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetBlockRequest) GetById() *BlockById
- func (x *GetBlockRequest) GetBySeqno() *BlockBySeqno
- func (x *GetBlockRequest) GetQuery() isGetBlockRequest_Query
- func (*GetBlockRequest) ProtoMessage()
- func (x *GetBlockRequest) ProtoReflect() protoreflect.Message
- func (x *GetBlockRequest) Reset()
- func (x *GetBlockRequest) String() string
- type GetBlockRequest_ById
- type GetBlockRequest_BySeqno
- type GetBlockResponse
- func (*GetBlockResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetBlockResponse) GetChunk() *BlockChunk
- func (x *GetBlockResponse) GetFound() *BlockFound
- func (x *GetBlockResponse) GetMsg() isGetBlockResponse_Msg
- func (x *GetBlockResponse) GetNotFound() *BlockNotFound
- func (*GetBlockResponse) ProtoMessage()
- func (x *GetBlockResponse) ProtoReflect() protoreflect.Message
- func (x *GetBlockResponse) Reset()
- func (x *GetBlockResponse) String() string
- type GetBlockResponse_Chunk
- type GetBlockResponse_Found
- type GetBlockResponse_NotFound
- type GetLibraryCellRequest
- func (*GetLibraryCellRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetLibraryCellRequest) GetHash() []byte
- func (*GetLibraryCellRequest) ProtoMessage()
- func (x *GetLibraryCellRequest) ProtoReflect() protoreflect.Message
- func (x *GetLibraryCellRequest) Reset()
- func (x *GetLibraryCellRequest) String() string
- type GetLibraryCellResponse
- func (*GetLibraryCellResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetLibraryCellResponse) GetFound() *LibraryCellFound
- func (x *GetLibraryCellResponse) GetLibrary() isGetLibraryCellResponse_Library
- func (x *GetLibraryCellResponse) GetNotFound() *LibraryCellNotFound
- func (*GetLibraryCellResponse) ProtoMessage()
- func (x *GetLibraryCellResponse) ProtoReflect() protoreflect.Message
- func (x *GetLibraryCellResponse) Reset()
- func (x *GetLibraryCellResponse) String() string
- type GetLibraryCellResponse_Found
- type GetLibraryCellResponse_NotFound
- type GetLibraryCellsRequest
- func (*GetLibraryCellsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetLibraryCellsRequest) GetHashes() [][]byte
- func (*GetLibraryCellsRequest) ProtoMessage()
- func (x *GetLibraryCellsRequest) ProtoReflect() protoreflect.Message
- func (x *GetLibraryCellsRequest) Reset()
- func (x *GetLibraryCellsRequest) String() string
- type GetLibraryCellsResponse
- func (*GetLibraryCellsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetLibraryCellsResponse) GetEntries() []*LibraryCellsBatchEntry
- func (x *GetLibraryCellsResponse) GetMcStateInfo() *McStateInfo
- func (*GetLibraryCellsResponse) ProtoMessage()
- func (x *GetLibraryCellsResponse) ProtoReflect() protoreflect.Message
- func (x *GetLibraryCellsResponse) Reset()
- func (x *GetLibraryCellsResponse) String() string
- type GetShardAccountRequest
- func (*GetShardAccountRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetShardAccountRequest) GetAddress() []byte
- func (x *GetShardAccountRequest) GetAtBlock() isGetShardAccountRequest_AtBlock
- func (x *GetShardAccountRequest) GetById() *BlockById
- func (x *GetShardAccountRequest) GetBySeqno() *BlockBySeqno
- func (x *GetShardAccountRequest) GetLatest() *LatestBlock
- func (x *GetShardAccountRequest) GetWithProof() bool
- func (x *GetShardAccountRequest) GetWorkchain() int32
- func (*GetShardAccountRequest) ProtoMessage()
- func (x *GetShardAccountRequest) ProtoReflect() protoreflect.Message
- func (x *GetShardAccountRequest) Reset()
- func (x *GetShardAccountRequest) String() string
- type GetShardAccountRequest_ById
- type GetShardAccountRequest_BySeqno
- type GetShardAccountRequest_Latest
- type GetShardAccountResponse
- func (*GetShardAccountResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetShardAccountResponse) GetAccessed() *ShardAccount
- func (x *GetShardAccountResponse) GetAccount() isGetShardAccountResponse_Account
- func (x *GetShardAccountResponse) GetBlockNotFound() *BlockNotFound
- func (*GetShardAccountResponse) ProtoMessage()
- func (x *GetShardAccountResponse) ProtoReflect() protoreflect.Message
- func (x *GetShardAccountResponse) Reset()
- func (x *GetShardAccountResponse) String() string
- type GetShardAccountResponse_Accessed
- type GetShardAccountResponse_BlockNotFound
- type GetStatusRequest
- type GetStatusResponse
- func (*GetStatusResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetStatusResponse) GetInitBlockSeqno() uint32
- func (x *GetStatusResponse) GetMcStateInfo() *McStateInfo
- func (x *GetStatusResponse) GetTimestamp() uint64
- func (x *GetStatusResponse) GetVersion() uint32
- func (x *GetStatusResponse) GetZerostateFileHash() []byte
- func (x *GetStatusResponse) GetZerostateRootHash() []byte
- func (*GetStatusResponse) ProtoMessage()
- func (x *GetStatusResponse) ProtoReflect() protoreflect.Message
- func (x *GetStatusResponse) Reset()
- func (x *GetStatusResponse) String() string
- type LatestBlock
- type LibraryCellFound
- func (*LibraryCellFound) Descriptor() ([]byte, []int)deprecated
- func (x *LibraryCellFound) GetCell() []byte
- func (x *LibraryCellFound) GetMcStateInfo() *McStateInfo
- func (*LibraryCellFound) ProtoMessage()
- func (x *LibraryCellFound) ProtoReflect() protoreflect.Message
- func (x *LibraryCellFound) Reset()
- func (x *LibraryCellFound) String() string
- type LibraryCellNotFound
- func (*LibraryCellNotFound) Descriptor() ([]byte, []int)deprecated
- func (x *LibraryCellNotFound) GetMcStateInfo() *McStateInfo
- func (*LibraryCellNotFound) ProtoMessage()
- func (x *LibraryCellNotFound) ProtoReflect() protoreflect.Message
- func (x *LibraryCellNotFound) Reset()
- func (x *LibraryCellNotFound) String() string
- type LibraryCellsBatchEntry
- func (*LibraryCellsBatchEntry) Descriptor() ([]byte, []int)deprecated
- func (x *LibraryCellsBatchEntry) GetCell() []byte
- func (x *LibraryCellsBatchEntry) GetHash() []byte
- func (*LibraryCellsBatchEntry) ProtoMessage()
- func (x *LibraryCellsBatchEntry) ProtoReflect() protoreflect.Message
- func (x *LibraryCellsBatchEntry) Reset()
- func (x *LibraryCellsBatchEntry) String() string
- type McStateInfo
- func (*McStateInfo) Descriptor() ([]byte, []int)deprecated
- func (x *McStateInfo) GetLt() uint64
- func (x *McStateInfo) GetMcSeqno() uint32
- func (x *McStateInfo) GetUtime() uint32
- func (*McStateInfo) ProtoMessage()
- func (x *McStateInfo) ProtoReflect() protoreflect.Message
- func (x *McStateInfo) Reset()
- func (x *McStateInfo) String() string
- type NewMasterchainBlock
- func (*NewMasterchainBlock) Descriptor() ([]byte, []int)deprecated
- func (x *NewMasterchainBlock) GetMcBlockId() *BlockId
- func (x *NewMasterchainBlock) GetMcStateInfo() *McStateInfo
- func (x *NewMasterchainBlock) GetShardBlockIds() []*BlockId
- func (x *NewMasterchainBlock) GetShardDescription() []*ShardDescription
- func (*NewMasterchainBlock) ProtoMessage()
- func (x *NewMasterchainBlock) ProtoReflect() protoreflect.Message
- func (x *NewMasterchainBlock) Reset()
- func (x *NewMasterchainBlock) String() string
- type SendMessageRequest
- func (*SendMessageRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SendMessageRequest) GetMessage() []byte
- func (*SendMessageRequest) ProtoMessage()
- func (x *SendMessageRequest) ProtoReflect() protoreflect.Message
- func (x *SendMessageRequest) Reset()
- func (x *SendMessageRequest) String() string
- type SendMessageResponse
- func (*SendMessageResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SendMessageResponse) GetDeliveredTo() uint32
- func (*SendMessageResponse) ProtoMessage()
- func (x *SendMessageResponse) ProtoReflect() protoreflect.Message
- func (x *SendMessageResponse) Reset()
- func (x *SendMessageResponse) String() string
- type ShardAccount
- func (*ShardAccount) Descriptor() ([]byte, []int)deprecated
- func (x *ShardAccount) GetAccountState() []byte
- func (x *ShardAccount) GetLastTransaction() *TransactionId
- func (x *ShardAccount) GetMcStateInfo() *McStateInfo
- func (x *ShardAccount) GetProof() []byte
- func (*ShardAccount) ProtoMessage()
- func (x *ShardAccount) ProtoReflect() protoreflect.Message
- func (x *ShardAccount) Reset()
- func (x *ShardAccount) String() string
- type ShardAccountNotFound
- func (*ShardAccountNotFound) Descriptor() ([]byte, []int)deprecated
- func (x *ShardAccountNotFound) GetMcStateInfo() *McStateInfo
- func (*ShardAccountNotFound) ProtoMessage()
- func (x *ShardAccountNotFound) ProtoReflect() protoreflect.Message
- func (x *ShardAccountNotFound) Reset()
- func (x *ShardAccountNotFound) String() string
- type ShardDescription
- func (*ShardDescription) Descriptor() ([]byte, []int)deprecated
- func (x *ShardDescription) GetEndLt() uint64
- func (x *ShardDescription) GetLatestBlockId() *BlockId
- func (x *ShardDescription) GetRegMcSeqno() uint32
- func (x *ShardDescription) GetUtime() uint32
- func (*ShardDescription) ProtoMessage()
- func (x *ShardDescription) ProtoReflect() protoreflect.Message
- func (x *ShardDescription) Reset()
- func (x *ShardDescription) String() string
- type TransactionId
- func (*TransactionId) Descriptor() ([]byte, []int)deprecated
- func (x *TransactionId) GetHash() []byte
- func (x *TransactionId) GetLt() uint64
- func (*TransactionId) ProtoMessage()
- func (x *TransactionId) ProtoReflect() protoreflect.Message
- func (x *TransactionId) Reset()
- func (x *TransactionId) String() string
- type TychoIndexerClient
- type TychoIndexerServer
- type TychoIndexer_GetBlockClient
- type TychoIndexer_GetBlockServer
- type TychoIndexer_WatchBlockIdsClient
- type TychoIndexer_WatchBlockIdsServer
- type UnimplementedTychoIndexerServer
- func (UnimplementedTychoIndexerServer) GetBlock(*GetBlockRequest, grpc.ServerStreamingServer[GetBlockResponse]) error
- func (UnimplementedTychoIndexerServer) GetLibraryCell(context.Context, *GetLibraryCellRequest) (*GetLibraryCellResponse, error)
- func (UnimplementedTychoIndexerServer) GetLibraryCells(context.Context, *GetLibraryCellsRequest) (*GetLibraryCellsResponse, error)
- func (UnimplementedTychoIndexerServer) GetShardAccount(context.Context, *GetShardAccountRequest) (*GetShardAccountResponse, error)
- func (UnimplementedTychoIndexerServer) GetStatus(context.Context, *GetStatusRequest) (*GetStatusResponse, error)
- func (UnimplementedTychoIndexerServer) SendMessage(context.Context, *SendMessageRequest) (*SendMessageResponse, error)
- func (UnimplementedTychoIndexerServer) WatchBlockIds(*WatchBlockIdsRequest, grpc.ServerStreamingServer[WatchBlockIdsEvent]) error
- type UnsafeTychoIndexerServer
- type WatchBlockIdsEvent
- func (*WatchBlockIdsEvent) Descriptor() ([]byte, []int)deprecated
- func (x *WatchBlockIdsEvent) GetEvent() isWatchBlockIdsEvent_Event
- func (x *WatchBlockIdsEvent) GetNewMcBlock() *NewMasterchainBlock
- func (x *WatchBlockIdsEvent) GetRangeSkipped() *BlocksRangeSkipped
- func (*WatchBlockIdsEvent) ProtoMessage()
- func (x *WatchBlockIdsEvent) ProtoReflect() protoreflect.Message
- func (x *WatchBlockIdsEvent) Reset()
- func (x *WatchBlockIdsEvent) String() string
- type WatchBlockIdsEvent_NewMcBlock
- type WatchBlockIdsEvent_RangeSkipped
- type WatchBlockIdsRequest
- func (*WatchBlockIdsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *WatchBlockIdsRequest) GetSinceMcSeqno() uint32
- func (*WatchBlockIdsRequest) ProtoMessage()
- func (x *WatchBlockIdsRequest) ProtoReflect() protoreflect.Message
- func (x *WatchBlockIdsRequest) Reset()
- func (x *WatchBlockIdsRequest) String() string
Constants ¶
const ( TychoIndexer_GetStatus_FullMethodName = "/indexer.TychoIndexer/GetStatus" TychoIndexer_WatchBlockIds_FullMethodName = "/indexer.TychoIndexer/WatchBlockIds" TychoIndexer_GetBlock_FullMethodName = "/indexer.TychoIndexer/GetBlock" TychoIndexer_GetShardAccount_FullMethodName = "/indexer.TychoIndexer/GetShardAccount" TychoIndexer_GetLibraryCell_FullMethodName = "/indexer.TychoIndexer/GetLibraryCell" TychoIndexer_GetLibraryCells_FullMethodName = "/indexer.TychoIndexer/GetLibraryCells" TychoIndexer_SendMessage_FullMethodName = "/indexer.TychoIndexer/SendMessage" )
Variables ¶
var File_indexer_proto protoreflect.FileDescriptor
var TychoIndexer_ServiceDesc = grpc.ServiceDesc{ ServiceName: "indexer.TychoIndexer", HandlerType: (*TychoIndexerServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetStatus", Handler: _TychoIndexer_GetStatus_Handler, }, { MethodName: "GetShardAccount", Handler: _TychoIndexer_GetShardAccount_Handler, }, { MethodName: "GetLibraryCell", Handler: _TychoIndexer_GetLibraryCell_Handler, }, { MethodName: "GetLibraryCells", Handler: _TychoIndexer_GetLibraryCells_Handler, }, { MethodName: "SendMessage", Handler: _TychoIndexer_SendMessage_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "WatchBlockIds", Handler: _TychoIndexer_WatchBlockIds_Handler, ServerStreams: true, }, { StreamName: "GetBlock", Handler: _TychoIndexer_GetBlock_Handler, ServerStreams: true, }, }, Metadata: "indexer.proto", }
TychoIndexer_ServiceDesc is the grpc.ServiceDesc for TychoIndexer service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterTychoIndexerServer ¶
func RegisterTychoIndexerServer(s grpc.ServiceRegistrar, srv TychoIndexerServer)
Types ¶
type BlockById ¶
type BlockById struct {
Id *BlockId `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*BlockById) Descriptor
deprecated
func (*BlockById) ProtoMessage ¶
func (*BlockById) ProtoMessage()
func (*BlockById) ProtoReflect ¶
func (x *BlockById) ProtoReflect() protoreflect.Message
type BlockBySeqno ¶
type BlockBySeqno struct {
Workchain int32 `protobuf:"varint,1,opt,name=workchain,proto3" json:"workchain,omitempty"`
Shard uint64 `protobuf:"varint,2,opt,name=shard,proto3" json:"shard,omitempty"`
Seqno uint32 `protobuf:"varint,3,opt,name=seqno,proto3" json:"seqno,omitempty"`
// contains filtered or unexported fields
}
func (*BlockBySeqno) Descriptor
deprecated
func (*BlockBySeqno) Descriptor() ([]byte, []int)
Deprecated: Use BlockBySeqno.ProtoReflect.Descriptor instead.
func (*BlockBySeqno) GetSeqno ¶
func (x *BlockBySeqno) GetSeqno() uint32
func (*BlockBySeqno) GetShard ¶
func (x *BlockBySeqno) GetShard() uint64
func (*BlockBySeqno) GetWorkchain ¶
func (x *BlockBySeqno) GetWorkchain() int32
func (*BlockBySeqno) ProtoMessage ¶
func (*BlockBySeqno) ProtoMessage()
func (*BlockBySeqno) ProtoReflect ¶
func (x *BlockBySeqno) ProtoReflect() protoreflect.Message
func (*BlockBySeqno) Reset ¶
func (x *BlockBySeqno) Reset()
func (*BlockBySeqno) String ¶
func (x *BlockBySeqno) String() string
type BlockChunk ¶
type BlockChunk struct {
Offset uint64 `protobuf:"varint,1,opt,name=offset,proto3" json:"offset,omitempty"`
Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*BlockChunk) Descriptor
deprecated
func (*BlockChunk) Descriptor() ([]byte, []int)
Deprecated: Use BlockChunk.ProtoReflect.Descriptor instead.
func (*BlockChunk) GetData ¶
func (x *BlockChunk) GetData() []byte
func (*BlockChunk) GetOffset ¶
func (x *BlockChunk) GetOffset() uint64
func (*BlockChunk) ProtoMessage ¶
func (*BlockChunk) ProtoMessage()
func (*BlockChunk) ProtoReflect ¶
func (x *BlockChunk) ProtoReflect() protoreflect.Message
func (*BlockChunk) Reset ¶
func (x *BlockChunk) Reset()
func (*BlockChunk) String ¶
func (x *BlockChunk) String() string
type BlockFound ¶
type BlockFound struct {
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
TotalSize uint64 `protobuf:"varint,2,opt,name=totalSize,proto3" json:"totalSize,omitempty"`
MaxChunkSize uint64 `protobuf:"varint,3,opt,name=maxChunkSize,proto3" json:"maxChunkSize,omitempty"`
FirstChunk *BlockChunk `protobuf:"bytes,4,opt,name=firstChunk,proto3" json:"firstChunk,omitempty"`
// contains filtered or unexported fields
}
func (*BlockFound) Descriptor
deprecated
func (*BlockFound) Descriptor() ([]byte, []int)
Deprecated: Use BlockFound.ProtoReflect.Descriptor instead.
func (*BlockFound) GetFirstChunk ¶
func (x *BlockFound) GetFirstChunk() *BlockChunk
func (*BlockFound) GetMaxChunkSize ¶
func (x *BlockFound) GetMaxChunkSize() uint64
func (*BlockFound) GetMcStateInfo ¶
func (x *BlockFound) GetMcStateInfo() *McStateInfo
func (*BlockFound) GetTotalSize ¶
func (x *BlockFound) GetTotalSize() uint64
func (*BlockFound) ProtoMessage ¶
func (*BlockFound) ProtoMessage()
func (*BlockFound) ProtoReflect ¶
func (x *BlockFound) ProtoReflect() protoreflect.Message
func (*BlockFound) Reset ¶
func (x *BlockFound) Reset()
func (*BlockFound) String ¶
func (x *BlockFound) String() string
type BlockId ¶
type BlockId struct {
Workchain int32 `protobuf:"varint,1,opt,name=workchain,proto3" json:"workchain,omitempty"`
Shard uint64 `protobuf:"varint,2,opt,name=shard,proto3" json:"shard,omitempty"`
Seqno uint32 `protobuf:"varint,3,opt,name=seqno,proto3" json:"seqno,omitempty"`
RootHash []byte `protobuf:"bytes,4,opt,name=rootHash,proto3" json:"rootHash,omitempty"`
FileHash []byte `protobuf:"bytes,5,opt,name=fileHash,proto3" json:"fileHash,omitempty"`
// contains filtered or unexported fields
}
func (*BlockId) Descriptor
deprecated
func (*BlockId) GetFileHash ¶
func (*BlockId) GetRootHash ¶
func (*BlockId) GetWorkchain ¶
func (*BlockId) ProtoMessage ¶
func (*BlockId) ProtoMessage()
func (*BlockId) ProtoReflect ¶
func (x *BlockId) ProtoReflect() protoreflect.Message
type BlockNotFound ¶
type BlockNotFound struct {
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
// contains filtered or unexported fields
}
func (*BlockNotFound) Descriptor
deprecated
func (*BlockNotFound) Descriptor() ([]byte, []int)
Deprecated: Use BlockNotFound.ProtoReflect.Descriptor instead.
func (*BlockNotFound) GetMcStateInfo ¶
func (x *BlockNotFound) GetMcStateInfo() *McStateInfo
func (*BlockNotFound) ProtoMessage ¶
func (*BlockNotFound) ProtoMessage()
func (*BlockNotFound) ProtoReflect ¶
func (x *BlockNotFound) ProtoReflect() protoreflect.Message
func (*BlockNotFound) Reset ¶
func (x *BlockNotFound) Reset()
func (*BlockNotFound) String ¶
func (x *BlockNotFound) String() string
type BlocksRangeSkipped ¶
type BlocksRangeSkipped struct {
// Brief masterchain info at the moment of accessing the state.
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
// Seqno of the first masterchain block in the skipped range (included).
From uint32 `protobuf:"varint,2,opt,name=from,proto3" json:"from,omitempty"`
// Seqno of the last masterchain block in the skipped range (included).
To uint32 `protobuf:"varint,3,opt,name=to,proto3" json:"to,omitempty"`
// contains filtered or unexported fields
}
func (*BlocksRangeSkipped) Descriptor
deprecated
func (*BlocksRangeSkipped) Descriptor() ([]byte, []int)
Deprecated: Use BlocksRangeSkipped.ProtoReflect.Descriptor instead.
func (*BlocksRangeSkipped) GetFrom ¶
func (x *BlocksRangeSkipped) GetFrom() uint32
func (*BlocksRangeSkipped) GetMcStateInfo ¶
func (x *BlocksRangeSkipped) GetMcStateInfo() *McStateInfo
func (*BlocksRangeSkipped) GetTo ¶
func (x *BlocksRangeSkipped) GetTo() uint32
func (*BlocksRangeSkipped) ProtoMessage ¶
func (*BlocksRangeSkipped) ProtoMessage()
func (*BlocksRangeSkipped) ProtoReflect ¶
func (x *BlocksRangeSkipped) ProtoReflect() protoreflect.Message
func (*BlocksRangeSkipped) Reset ¶
func (x *BlocksRangeSkipped) Reset()
func (*BlocksRangeSkipped) String ¶
func (x *BlocksRangeSkipped) String() string
type GetBlockRequest ¶
type GetBlockRequest struct {
// Types that are valid to be assigned to Query:
//
// *GetBlockRequest_BySeqno
// *GetBlockRequest_ById
Query isGetBlockRequest_Query `protobuf_oneof:"query"`
// contains filtered or unexported fields
}
func (*GetBlockRequest) Descriptor
deprecated
func (*GetBlockRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetBlockRequest.ProtoReflect.Descriptor instead.
func (*GetBlockRequest) GetById ¶
func (x *GetBlockRequest) GetById() *BlockById
func (*GetBlockRequest) GetBySeqno ¶
func (x *GetBlockRequest) GetBySeqno() *BlockBySeqno
func (*GetBlockRequest) GetQuery ¶
func (x *GetBlockRequest) GetQuery() isGetBlockRequest_Query
func (*GetBlockRequest) ProtoMessage ¶
func (*GetBlockRequest) ProtoMessage()
func (*GetBlockRequest) ProtoReflect ¶
func (x *GetBlockRequest) ProtoReflect() protoreflect.Message
func (*GetBlockRequest) Reset ¶
func (x *GetBlockRequest) Reset()
func (*GetBlockRequest) String ¶
func (x *GetBlockRequest) String() string
type GetBlockRequest_ById ¶
type GetBlockRequest_ById struct {
// Searches for a block by its id.
ById *BlockById `protobuf:"bytes,2,opt,name=byId,proto3,oneof"`
}
type GetBlockRequest_BySeqno ¶
type GetBlockRequest_BySeqno struct {
// Searches for a block by seqno.
BySeqno *BlockBySeqno `protobuf:"bytes,1,opt,name=bySeqno,proto3,oneof"`
}
type GetBlockResponse ¶
type GetBlockResponse struct {
// Types that are valid to be assigned to Msg:
//
// *GetBlockResponse_NotFound
// *GetBlockResponse_Found
// *GetBlockResponse_Chunk
Msg isGetBlockResponse_Msg `protobuf_oneof:"msg"`
// contains filtered or unexported fields
}
func (*GetBlockResponse) Descriptor
deprecated
func (*GetBlockResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetBlockResponse.ProtoReflect.Descriptor instead.
func (*GetBlockResponse) GetChunk ¶
func (x *GetBlockResponse) GetChunk() *BlockChunk
func (*GetBlockResponse) GetFound ¶
func (x *GetBlockResponse) GetFound() *BlockFound
func (*GetBlockResponse) GetMsg ¶
func (x *GetBlockResponse) GetMsg() isGetBlockResponse_Msg
func (*GetBlockResponse) GetNotFound ¶
func (x *GetBlockResponse) GetNotFound() *BlockNotFound
func (*GetBlockResponse) ProtoMessage ¶
func (*GetBlockResponse) ProtoMessage()
func (*GetBlockResponse) ProtoReflect ¶
func (x *GetBlockResponse) ProtoReflect() protoreflect.Message
func (*GetBlockResponse) Reset ¶
func (x *GetBlockResponse) Reset()
func (*GetBlockResponse) String ¶
func (x *GetBlockResponse) String() string
type GetBlockResponse_Chunk ¶
type GetBlockResponse_Chunk struct {
// Subsequent messages in stream if it didn't fit into one chunk.
Chunk *BlockChunk `protobuf:"bytes,3,opt,name=chunk,proto3,oneof"`
}
type GetBlockResponse_Found ¶
type GetBlockResponse_Found struct {
// First message in stream if found.
Found *BlockFound `protobuf:"bytes,2,opt,name=found,proto3,oneof"`
}
type GetBlockResponse_NotFound ¶
type GetBlockResponse_NotFound struct {
// First and last message in stream if not found.
NotFound *BlockNotFound `protobuf:"bytes,1,opt,name=notFound,proto3,oneof"`
}
type GetLibraryCellRequest ¶
type GetLibraryCellRequest struct {
// 32 bytes of the library cell root hash.
Hash []byte `protobuf:"bytes,1,opt,name=hash,proto3" json:"hash,omitempty"`
// contains filtered or unexported fields
}
func (*GetLibraryCellRequest) Descriptor
deprecated
func (*GetLibraryCellRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetLibraryCellRequest.ProtoReflect.Descriptor instead.
func (*GetLibraryCellRequest) GetHash ¶
func (x *GetLibraryCellRequest) GetHash() []byte
func (*GetLibraryCellRequest) ProtoMessage ¶
func (*GetLibraryCellRequest) ProtoMessage()
func (*GetLibraryCellRequest) ProtoReflect ¶
func (x *GetLibraryCellRequest) ProtoReflect() protoreflect.Message
func (*GetLibraryCellRequest) Reset ¶
func (x *GetLibraryCellRequest) Reset()
func (*GetLibraryCellRequest) String ¶
func (x *GetLibraryCellRequest) String() string
type GetLibraryCellResponse ¶
type GetLibraryCellResponse struct {
// Types that are valid to be assigned to Library:
//
// *GetLibraryCellResponse_NotFound
// *GetLibraryCellResponse_Found
Library isGetLibraryCellResponse_Library `protobuf_oneof:"library"`
// contains filtered or unexported fields
}
func (*GetLibraryCellResponse) Descriptor
deprecated
func (*GetLibraryCellResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetLibraryCellResponse.ProtoReflect.Descriptor instead.
func (*GetLibraryCellResponse) GetFound ¶
func (x *GetLibraryCellResponse) GetFound() *LibraryCellFound
func (*GetLibraryCellResponse) GetLibrary ¶
func (x *GetLibraryCellResponse) GetLibrary() isGetLibraryCellResponse_Library
func (*GetLibraryCellResponse) GetNotFound ¶
func (x *GetLibraryCellResponse) GetNotFound() *LibraryCellNotFound
func (*GetLibraryCellResponse) ProtoMessage ¶
func (*GetLibraryCellResponse) ProtoMessage()
func (*GetLibraryCellResponse) ProtoReflect ¶
func (x *GetLibraryCellResponse) ProtoReflect() protoreflect.Message
func (*GetLibraryCellResponse) Reset ¶
func (x *GetLibraryCellResponse) Reset()
func (*GetLibraryCellResponse) String ¶
func (x *GetLibraryCellResponse) String() string
type GetLibraryCellResponse_Found ¶
type GetLibraryCellResponse_Found struct {
Found *LibraryCellFound `protobuf:"bytes,2,opt,name=found,proto3,oneof"`
}
type GetLibraryCellResponse_NotFound ¶
type GetLibraryCellResponse_NotFound struct {
NotFound *LibraryCellNotFound `protobuf:"bytes,1,opt,name=notFound,proto3,oneof"`
}
type GetLibraryCellsRequest ¶
type GetLibraryCellsRequest struct {
// An array of library root hashes (as 32 bytes).
// NOTE: All non-unique entries are deduplicated.
Hashes [][]byte `protobuf:"bytes,1,rep,name=hashes,proto3" json:"hashes,omitempty"`
// contains filtered or unexported fields
}
func (*GetLibraryCellsRequest) Descriptor
deprecated
func (*GetLibraryCellsRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetLibraryCellsRequest.ProtoReflect.Descriptor instead.
func (*GetLibraryCellsRequest) GetHashes ¶
func (x *GetLibraryCellsRequest) GetHashes() [][]byte
func (*GetLibraryCellsRequest) ProtoMessage ¶
func (*GetLibraryCellsRequest) ProtoMessage()
func (*GetLibraryCellsRequest) ProtoReflect ¶
func (x *GetLibraryCellsRequest) ProtoReflect() protoreflect.Message
func (*GetLibraryCellsRequest) Reset ¶
func (x *GetLibraryCellsRequest) Reset()
func (*GetLibraryCellsRequest) String ¶
func (x *GetLibraryCellsRequest) String() string
type GetLibraryCellsResponse ¶
type GetLibraryCellsResponse struct {
// Brief masterchain info at the moment of accessing the state.
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
// List of found libraries. Non-existing libraries are not included into this list.
Entries []*LibraryCellsBatchEntry `protobuf:"bytes,2,rep,name=entries,proto3" json:"entries,omitempty"`
// contains filtered or unexported fields
}
func (*GetLibraryCellsResponse) Descriptor
deprecated
func (*GetLibraryCellsResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetLibraryCellsResponse.ProtoReflect.Descriptor instead.
func (*GetLibraryCellsResponse) GetEntries ¶
func (x *GetLibraryCellsResponse) GetEntries() []*LibraryCellsBatchEntry
func (*GetLibraryCellsResponse) GetMcStateInfo ¶
func (x *GetLibraryCellsResponse) GetMcStateInfo() *McStateInfo
func (*GetLibraryCellsResponse) ProtoMessage ¶
func (*GetLibraryCellsResponse) ProtoMessage()
func (*GetLibraryCellsResponse) ProtoReflect ¶
func (x *GetLibraryCellsResponse) ProtoReflect() protoreflect.Message
func (*GetLibraryCellsResponse) Reset ¶
func (x *GetLibraryCellsResponse) Reset()
func (*GetLibraryCellsResponse) String ¶
func (x *GetLibraryCellsResponse) String() string
type GetShardAccountRequest ¶
type GetShardAccountRequest struct {
// Workchain part of the address (int8 actually).
Workchain int32 `protobuf:"varint,1,opt,name=workchain,proto3" json:"workchain,omitempty"`
// 32 bytes of the hash part of the address.
Address []byte `protobuf:"bytes,2,opt,name=address,proto3" json:"address,omitempty"`
// Whether to compute a separate proof that account state is included into a shard state.
WithProof bool `protobuf:"varint,3,opt,name=withProof,proto3" json:"withProof,omitempty"`
// Find account state at the time of a specific block
//
// Types that are valid to be assigned to AtBlock:
//
// *GetShardAccountRequest_Latest
// *GetShardAccountRequest_BySeqno
// *GetShardAccountRequest_ById
AtBlock isGetShardAccountRequest_AtBlock `protobuf_oneof:"atBlock"`
// contains filtered or unexported fields
}
func (*GetShardAccountRequest) Descriptor
deprecated
func (*GetShardAccountRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetShardAccountRequest.ProtoReflect.Descriptor instead.
func (*GetShardAccountRequest) GetAddress ¶
func (x *GetShardAccountRequest) GetAddress() []byte
func (*GetShardAccountRequest) GetAtBlock ¶
func (x *GetShardAccountRequest) GetAtBlock() isGetShardAccountRequest_AtBlock
func (*GetShardAccountRequest) GetById ¶
func (x *GetShardAccountRequest) GetById() *BlockById
func (*GetShardAccountRequest) GetBySeqno ¶
func (x *GetShardAccountRequest) GetBySeqno() *BlockBySeqno
func (*GetShardAccountRequest) GetLatest ¶
func (x *GetShardAccountRequest) GetLatest() *LatestBlock
func (*GetShardAccountRequest) GetWithProof ¶
func (x *GetShardAccountRequest) GetWithProof() bool
func (*GetShardAccountRequest) GetWorkchain ¶
func (x *GetShardAccountRequest) GetWorkchain() int32
func (*GetShardAccountRequest) ProtoMessage ¶
func (*GetShardAccountRequest) ProtoMessage()
func (*GetShardAccountRequest) ProtoReflect ¶
func (x *GetShardAccountRequest) ProtoReflect() protoreflect.Message
func (*GetShardAccountRequest) Reset ¶
func (x *GetShardAccountRequest) Reset()
func (*GetShardAccountRequest) String ¶
func (x *GetShardAccountRequest) String() string
type GetShardAccountRequest_ById ¶
type GetShardAccountRequest_ById struct {
// Searches for a block by its id.
ById *BlockById `protobuf:"bytes,6,opt,name=byId,proto3,oneof"`
}
type GetShardAccountRequest_BySeqno ¶
type GetShardAccountRequest_BySeqno struct {
// Searches for a block by seqno.
BySeqno *BlockBySeqno `protobuf:"bytes,5,opt,name=bySeqno,proto3,oneof"`
}
type GetShardAccountRequest_Latest ¶
type GetShardAccountRequest_Latest struct {
// Uses the latest states "edge".
Latest *LatestBlock `protobuf:"bytes,4,opt,name=latest,proto3,oneof"`
}
type GetShardAccountResponse ¶
type GetShardAccountResponse struct {
// Types that are valid to be assigned to Account:
//
// *GetShardAccountResponse_BlockNotFound
// *GetShardAccountResponse_Accessed
Account isGetShardAccountResponse_Account `protobuf_oneof:"account"`
// contains filtered or unexported fields
}
func (*GetShardAccountResponse) Descriptor
deprecated
func (*GetShardAccountResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetShardAccountResponse.ProtoReflect.Descriptor instead.
func (*GetShardAccountResponse) GetAccessed ¶
func (x *GetShardAccountResponse) GetAccessed() *ShardAccount
func (*GetShardAccountResponse) GetAccount ¶
func (x *GetShardAccountResponse) GetAccount() isGetShardAccountResponse_Account
func (*GetShardAccountResponse) GetBlockNotFound ¶
func (x *GetShardAccountResponse) GetBlockNotFound() *BlockNotFound
func (*GetShardAccountResponse) ProtoMessage ¶
func (*GetShardAccountResponse) ProtoMessage()
func (*GetShardAccountResponse) ProtoReflect ¶
func (x *GetShardAccountResponse) ProtoReflect() protoreflect.Message
func (*GetShardAccountResponse) Reset ¶
func (x *GetShardAccountResponse) Reset()
func (*GetShardAccountResponse) String ¶
func (x *GetShardAccountResponse) String() string
type GetShardAccountResponse_Accessed ¶
type GetShardAccountResponse_Accessed struct {
// Shard account info.
Accessed *ShardAccount `protobuf:"bytes,2,opt,name=accessed,proto3,oneof"`
}
type GetShardAccountResponse_BlockNotFound ¶
type GetShardAccountResponse_BlockNotFound struct {
// Specified block not found.
BlockNotFound *BlockNotFound `protobuf:"bytes,1,opt,name=blockNotFound,proto3,oneof"`
}
type GetStatusRequest ¶
type GetStatusRequest struct {
// contains filtered or unexported fields
}
func (*GetStatusRequest) Descriptor
deprecated
func (*GetStatusRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetStatusRequest.ProtoReflect.Descriptor instead.
func (*GetStatusRequest) ProtoMessage ¶
func (*GetStatusRequest) ProtoMessage()
func (*GetStatusRequest) ProtoReflect ¶
func (x *GetStatusRequest) ProtoReflect() protoreflect.Message
func (*GetStatusRequest) Reset ¶
func (x *GetStatusRequest) Reset()
func (*GetStatusRequest) String ¶
func (x *GetStatusRequest) String() string
type GetStatusResponse ¶
type GetStatusResponse struct {
// Latest known masterchain info, or "None" if the node is not ready yet.
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3,oneof" json:"mcStateInfo,omitempty"`
// Local server unix timestamp in milliseconds.
Timestamp uint64 `protobuf:"varint,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// Blockchain zerostate id.
ZerostateRootHash []byte `protobuf:"bytes,3,opt,name=zerostateRootHash,proto3" json:"zerostateRootHash,omitempty"`
// Blockchain zerostate id.
ZerostateFileHash []byte `protobuf:"bytes,4,opt,name=zerostateFileHash,proto3" json:"zerostateFileHash,omitempty"`
// From which masterchain block the node started working.
InitBlockSeqno uint32 `protobuf:"varint,5,opt,name=initBlockSeqno,proto3" json:"initBlockSeqno,omitempty"`
// Node version (encoded as octets, e.g. version 1.2.3 will be 0x00010203)
Version uint32 `protobuf:"varint,6,opt,name=version,proto3" json:"version,omitempty"`
// contains filtered or unexported fields
}
func (*GetStatusResponse) Descriptor
deprecated
func (*GetStatusResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetStatusResponse.ProtoReflect.Descriptor instead.
func (*GetStatusResponse) GetInitBlockSeqno ¶
func (x *GetStatusResponse) GetInitBlockSeqno() uint32
func (*GetStatusResponse) GetMcStateInfo ¶
func (x *GetStatusResponse) GetMcStateInfo() *McStateInfo
func (*GetStatusResponse) GetTimestamp ¶
func (x *GetStatusResponse) GetTimestamp() uint64
func (*GetStatusResponse) GetVersion ¶
func (x *GetStatusResponse) GetVersion() uint32
func (*GetStatusResponse) GetZerostateFileHash ¶
func (x *GetStatusResponse) GetZerostateFileHash() []byte
func (*GetStatusResponse) GetZerostateRootHash ¶
func (x *GetStatusResponse) GetZerostateRootHash() []byte
func (*GetStatusResponse) ProtoMessage ¶
func (*GetStatusResponse) ProtoMessage()
func (*GetStatusResponse) ProtoReflect ¶
func (x *GetStatusResponse) ProtoReflect() protoreflect.Message
func (*GetStatusResponse) Reset ¶
func (x *GetStatusResponse) Reset()
func (*GetStatusResponse) String ¶
func (x *GetStatusResponse) String() string
type LatestBlock ¶
type LatestBlock struct {
// contains filtered or unexported fields
}
func (*LatestBlock) Descriptor
deprecated
func (*LatestBlock) Descriptor() ([]byte, []int)
Deprecated: Use LatestBlock.ProtoReflect.Descriptor instead.
func (*LatestBlock) ProtoMessage ¶
func (*LatestBlock) ProtoMessage()
func (*LatestBlock) ProtoReflect ¶
func (x *LatestBlock) ProtoReflect() protoreflect.Message
func (*LatestBlock) Reset ¶
func (x *LatestBlock) Reset()
func (*LatestBlock) String ¶
func (x *LatestBlock) String() string
type LibraryCellFound ¶
type LibraryCellFound struct {
// Brief masterchain info at the moment of accessing the state.
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
// BOC-encoded library code.
Cell []byte `protobuf:"bytes,2,opt,name=cell,proto3" json:"cell,omitempty"`
// contains filtered or unexported fields
}
func (*LibraryCellFound) Descriptor
deprecated
func (*LibraryCellFound) Descriptor() ([]byte, []int)
Deprecated: Use LibraryCellFound.ProtoReflect.Descriptor instead.
func (*LibraryCellFound) GetCell ¶
func (x *LibraryCellFound) GetCell() []byte
func (*LibraryCellFound) GetMcStateInfo ¶
func (x *LibraryCellFound) GetMcStateInfo() *McStateInfo
func (*LibraryCellFound) ProtoMessage ¶
func (*LibraryCellFound) ProtoMessage()
func (*LibraryCellFound) ProtoReflect ¶
func (x *LibraryCellFound) ProtoReflect() protoreflect.Message
func (*LibraryCellFound) Reset ¶
func (x *LibraryCellFound) Reset()
func (*LibraryCellFound) String ¶
func (x *LibraryCellFound) String() string
type LibraryCellNotFound ¶
type LibraryCellNotFound struct {
// Brief masterchain info at the moment of accessing the state.
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
// contains filtered or unexported fields
}
func (*LibraryCellNotFound) Descriptor
deprecated
func (*LibraryCellNotFound) Descriptor() ([]byte, []int)
Deprecated: Use LibraryCellNotFound.ProtoReflect.Descriptor instead.
func (*LibraryCellNotFound) GetMcStateInfo ¶
func (x *LibraryCellNotFound) GetMcStateInfo() *McStateInfo
func (*LibraryCellNotFound) ProtoMessage ¶
func (*LibraryCellNotFound) ProtoMessage()
func (*LibraryCellNotFound) ProtoReflect ¶
func (x *LibraryCellNotFound) ProtoReflect() protoreflect.Message
func (*LibraryCellNotFound) Reset ¶
func (x *LibraryCellNotFound) Reset()
func (*LibraryCellNotFound) String ¶
func (x *LibraryCellNotFound) String() string
type LibraryCellsBatchEntry ¶
type LibraryCellsBatchEntry struct {
// 32 bytes of the library cell root hash.
Hash []byte `protobuf:"bytes,1,opt,name=hash,proto3" json:"hash,omitempty"`
// BOC-encoded library code.
Cell []byte `protobuf:"bytes,2,opt,name=cell,proto3" json:"cell,omitempty"`
// contains filtered or unexported fields
}
func (*LibraryCellsBatchEntry) Descriptor
deprecated
func (*LibraryCellsBatchEntry) Descriptor() ([]byte, []int)
Deprecated: Use LibraryCellsBatchEntry.ProtoReflect.Descriptor instead.
func (*LibraryCellsBatchEntry) GetCell ¶
func (x *LibraryCellsBatchEntry) GetCell() []byte
func (*LibraryCellsBatchEntry) GetHash ¶
func (x *LibraryCellsBatchEntry) GetHash() []byte
func (*LibraryCellsBatchEntry) ProtoMessage ¶
func (*LibraryCellsBatchEntry) ProtoMessage()
func (*LibraryCellsBatchEntry) ProtoReflect ¶
func (x *LibraryCellsBatchEntry) ProtoReflect() protoreflect.Message
func (*LibraryCellsBatchEntry) Reset ¶
func (x *LibraryCellsBatchEntry) Reset()
func (*LibraryCellsBatchEntry) String ¶
func (x *LibraryCellsBatchEntry) String() string
type McStateInfo ¶
type McStateInfo struct {
// Masterchain block seqno.
McSeqno uint32 `protobuf:"varint,1,opt,name=mcSeqno,proto3" json:"mcSeqno,omitempty"`
// Masterchain LT (end_lt).
Lt uint64 `protobuf:"varint,2,opt,name=lt,proto3" json:"lt,omitempty"`
// Masterchain unix timestamp.
Utime uint32 `protobuf:"varint,3,opt,name=utime,proto3" json:"utime,omitempty"`
// contains filtered or unexported fields
}
func (*McStateInfo) Descriptor
deprecated
func (*McStateInfo) Descriptor() ([]byte, []int)
Deprecated: Use McStateInfo.ProtoReflect.Descriptor instead.
func (*McStateInfo) GetLt ¶
func (x *McStateInfo) GetLt() uint64
func (*McStateInfo) GetMcSeqno ¶
func (x *McStateInfo) GetMcSeqno() uint32
func (*McStateInfo) GetUtime ¶
func (x *McStateInfo) GetUtime() uint32
func (*McStateInfo) ProtoMessage ¶
func (*McStateInfo) ProtoMessage()
func (*McStateInfo) ProtoReflect ¶
func (x *McStateInfo) ProtoReflect() protoreflect.Message
func (*McStateInfo) Reset ¶
func (x *McStateInfo) Reset()
func (*McStateInfo) String ¶
func (x *McStateInfo) String() string
type NewMasterchainBlock ¶
type NewMasterchainBlock struct {
// Brief masterchain info at the moment of accessing the state.
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
// The id of the masterchain block.
McBlockId *BlockId `protobuf:"bytes,2,opt,name=mcBlockId,proto3" json:"mcBlockId,omitempty"`
// Brief info for all shards in all workchains other than masterchain.
ShardDescription []*ShardDescription `protobuf:"bytes,3,rep,name=shardDescription,proto3" json:"shardDescription,omitempty"`
// All shard block ids since the previous masterchain block.
// (can be empty if no new shard blocks were produced).
ShardBlockIds []*BlockId `protobuf:"bytes,4,rep,name=shardBlockIds,proto3" json:"shardBlockIds,omitempty"`
// contains filtered or unexported fields
}
func (*NewMasterchainBlock) Descriptor
deprecated
func (*NewMasterchainBlock) Descriptor() ([]byte, []int)
Deprecated: Use NewMasterchainBlock.ProtoReflect.Descriptor instead.
func (*NewMasterchainBlock) GetMcBlockId ¶
func (x *NewMasterchainBlock) GetMcBlockId() *BlockId
func (*NewMasterchainBlock) GetMcStateInfo ¶
func (x *NewMasterchainBlock) GetMcStateInfo() *McStateInfo
func (*NewMasterchainBlock) GetShardBlockIds ¶
func (x *NewMasterchainBlock) GetShardBlockIds() []*BlockId
func (*NewMasterchainBlock) GetShardDescription ¶
func (x *NewMasterchainBlock) GetShardDescription() []*ShardDescription
func (*NewMasterchainBlock) ProtoMessage ¶
func (*NewMasterchainBlock) ProtoMessage()
func (*NewMasterchainBlock) ProtoReflect ¶
func (x *NewMasterchainBlock) ProtoReflect() protoreflect.Message
func (*NewMasterchainBlock) Reset ¶
func (x *NewMasterchainBlock) Reset()
func (*NewMasterchainBlock) String ¶
func (x *NewMasterchainBlock) String() string
type SendMessageRequest ¶
type SendMessageRequest struct {
// BOC-encoded `Message`.
Message []byte `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*SendMessageRequest) Descriptor
deprecated
func (*SendMessageRequest) Descriptor() ([]byte, []int)
Deprecated: Use SendMessageRequest.ProtoReflect.Descriptor instead.
func (*SendMessageRequest) GetMessage ¶
func (x *SendMessageRequest) GetMessage() []byte
func (*SendMessageRequest) ProtoMessage ¶
func (*SendMessageRequest) ProtoMessage()
func (*SendMessageRequest) ProtoReflect ¶
func (x *SendMessageRequest) ProtoReflect() protoreflect.Message
func (*SendMessageRequest) Reset ¶
func (x *SendMessageRequest) Reset()
func (*SendMessageRequest) String ¶
func (x *SendMessageRequest) String() string
type SendMessageResponse ¶
type SendMessageResponse struct {
// Number of nodes this message was successfully delivered to.
DeliveredTo uint32 `protobuf:"varint,1,opt,name=deliveredTo,proto3" json:"deliveredTo,omitempty"`
// contains filtered or unexported fields
}
func (*SendMessageResponse) Descriptor
deprecated
func (*SendMessageResponse) Descriptor() ([]byte, []int)
Deprecated: Use SendMessageResponse.ProtoReflect.Descriptor instead.
func (*SendMessageResponse) GetDeliveredTo ¶
func (x *SendMessageResponse) GetDeliveredTo() uint32
func (*SendMessageResponse) ProtoMessage ¶
func (*SendMessageResponse) ProtoMessage()
func (*SendMessageResponse) ProtoReflect ¶
func (x *SendMessageResponse) ProtoReflect() protoreflect.Message
func (*SendMessageResponse) Reset ¶
func (x *SendMessageResponse) Reset()
func (*SendMessageResponse) String ¶
func (x *SendMessageResponse) String() string
type ShardAccount ¶
type ShardAccount struct {
// Brief masterchain info at the moment of accessing the state.
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
// BOC-encoded `ShardAccount` (if found).
AccountState []byte `protobuf:"bytes,2,opt,name=accountState,proto3,oneof" json:"accountState,omitempty"`
// BOC-encoded collection of proofs. Consists of two roots,
// the first one is shard state root proof cell
// and the second is account-in-state proof.
Proof []byte `protobuf:"bytes,3,opt,name=proof,proto3,oneof" json:"proof,omitempty"`
// The latest known transaction at the time of accessing the state (if any).
// Can be used instead of `proof` if only something like LT is needed.
LastTransaction *TransactionId `protobuf:"bytes,4,opt,name=lastTransaction,proto3,oneof" json:"lastTransaction,omitempty"`
// contains filtered or unexported fields
}
func (*ShardAccount) Descriptor
deprecated
func (*ShardAccount) Descriptor() ([]byte, []int)
Deprecated: Use ShardAccount.ProtoReflect.Descriptor instead.
func (*ShardAccount) GetAccountState ¶
func (x *ShardAccount) GetAccountState() []byte
func (*ShardAccount) GetLastTransaction ¶
func (x *ShardAccount) GetLastTransaction() *TransactionId
func (*ShardAccount) GetMcStateInfo ¶
func (x *ShardAccount) GetMcStateInfo() *McStateInfo
func (*ShardAccount) GetProof ¶
func (x *ShardAccount) GetProof() []byte
func (*ShardAccount) ProtoMessage ¶
func (*ShardAccount) ProtoMessage()
func (*ShardAccount) ProtoReflect ¶
func (x *ShardAccount) ProtoReflect() protoreflect.Message
func (*ShardAccount) Reset ¶
func (x *ShardAccount) Reset()
func (*ShardAccount) String ¶
func (x *ShardAccount) String() string
type ShardAccountNotFound ¶
type ShardAccountNotFound struct {
// Brief masterchain info at the moment of accessing the state.
McStateInfo *McStateInfo `protobuf:"bytes,1,opt,name=mcStateInfo,proto3" json:"mcStateInfo,omitempty"`
// contains filtered or unexported fields
}
func (*ShardAccountNotFound) Descriptor
deprecated
func (*ShardAccountNotFound) Descriptor() ([]byte, []int)
Deprecated: Use ShardAccountNotFound.ProtoReflect.Descriptor instead.
func (*ShardAccountNotFound) GetMcStateInfo ¶
func (x *ShardAccountNotFound) GetMcStateInfo() *McStateInfo
func (*ShardAccountNotFound) ProtoMessage ¶
func (*ShardAccountNotFound) ProtoMessage()
func (*ShardAccountNotFound) ProtoReflect ¶
func (x *ShardAccountNotFound) ProtoReflect() protoreflect.Message
func (*ShardAccountNotFound) Reset ¶
func (x *ShardAccountNotFound) Reset()
func (*ShardAccountNotFound) String ¶
func (x *ShardAccountNotFound) String() string
type ShardDescription ¶
type ShardDescription struct {
// Id of the latest block in that shard.
LatestBlockId *BlockId `protobuf:"bytes,1,opt,name=latestBlockId,proto3" json:"latestBlockId,omitempty"`
// LT of the latest block in that shard.
EndLt uint64 `protobuf:"varint,2,opt,name=endLt,proto3" json:"endLt,omitempty"`
// Unix timestamp when the latest block was generated.
Utime uint32 `protobuf:"varint,3,opt,name=utime,proto3" json:"utime,omitempty"`
// The latest known masterchain block at the time of shard generation.
RegMcSeqno uint32 `protobuf:"varint,4,opt,name=regMcSeqno,proto3" json:"regMcSeqno,omitempty"`
// contains filtered or unexported fields
}
func (*ShardDescription) Descriptor
deprecated
func (*ShardDescription) Descriptor() ([]byte, []int)
Deprecated: Use ShardDescription.ProtoReflect.Descriptor instead.
func (*ShardDescription) GetEndLt ¶
func (x *ShardDescription) GetEndLt() uint64
func (*ShardDescription) GetLatestBlockId ¶
func (x *ShardDescription) GetLatestBlockId() *BlockId
func (*ShardDescription) GetRegMcSeqno ¶
func (x *ShardDescription) GetRegMcSeqno() uint32
func (*ShardDescription) GetUtime ¶
func (x *ShardDescription) GetUtime() uint32
func (*ShardDescription) ProtoMessage ¶
func (*ShardDescription) ProtoMessage()
func (*ShardDescription) ProtoReflect ¶
func (x *ShardDescription) ProtoReflect() protoreflect.Message
func (*ShardDescription) Reset ¶
func (x *ShardDescription) Reset()
func (*ShardDescription) String ¶
func (x *ShardDescription) String() string
type TransactionId ¶
type TransactionId struct {
// Logical time of transaction.
Lt uint64 `protobuf:"varint,1,opt,name=lt,proto3" json:"lt,omitempty"`
// 32 bytes of the transaction hash.
Hash []byte `protobuf:"bytes,2,opt,name=hash,proto3" json:"hash,omitempty"`
// contains filtered or unexported fields
}
func (*TransactionId) Descriptor
deprecated
func (*TransactionId) Descriptor() ([]byte, []int)
Deprecated: Use TransactionId.ProtoReflect.Descriptor instead.
func (*TransactionId) GetHash ¶
func (x *TransactionId) GetHash() []byte
func (*TransactionId) GetLt ¶
func (x *TransactionId) GetLt() uint64
func (*TransactionId) ProtoMessage ¶
func (*TransactionId) ProtoMessage()
func (*TransactionId) ProtoReflect ¶
func (x *TransactionId) ProtoReflect() protoreflect.Message
func (*TransactionId) Reset ¶
func (x *TransactionId) Reset()
func (*TransactionId) String ¶
func (x *TransactionId) String() string
type TychoIndexerClient ¶
type TychoIndexerClient interface {
// Indexer node status.
GetStatus(ctx context.Context, in *GetStatusRequest, opts ...grpc.CallOption) (*GetStatusResponse, error)
// Subscribe for block events.
WatchBlockIds(ctx context.Context, in *WatchBlockIdsRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[WatchBlockIdsEvent], error)
// Returns a stream of BOC-encoded block data chunks if found,
// otherwise returns a stream with a single block-not-found message.
GetBlock(ctx context.Context, in *GetBlockRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[GetBlockResponse], error)
// Search for a shard account state.
GetShardAccount(ctx context.Context, in *GetShardAccountRequest, opts ...grpc.CallOption) (*GetShardAccountResponse, error)
// Search for a library code.
GetLibraryCell(ctx context.Context, in *GetLibraryCellRequest, opts ...grpc.CallOption) (*GetLibraryCellResponse, error)
// Search for multiple libraries.
GetLibraryCells(ctx context.Context, in *GetLibraryCellsRequest, opts ...grpc.CallOption) (*GetLibraryCellsResponse, error)
// Send message to validators.
SendMessage(ctx context.Context, in *SendMessageRequest, opts ...grpc.CallOption) (*SendMessageResponse, error)
}
TychoIndexerClient is the client API for TychoIndexer service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewTychoIndexerClient ¶
func NewTychoIndexerClient(cc grpc.ClientConnInterface) TychoIndexerClient
type TychoIndexerServer ¶
type TychoIndexerServer interface {
// Indexer node status.
GetStatus(context.Context, *GetStatusRequest) (*GetStatusResponse, error)
// Subscribe for block events.
WatchBlockIds(*WatchBlockIdsRequest, grpc.ServerStreamingServer[WatchBlockIdsEvent]) error
// Returns a stream of BOC-encoded block data chunks if found,
// otherwise returns a stream with a single block-not-found message.
GetBlock(*GetBlockRequest, grpc.ServerStreamingServer[GetBlockResponse]) error
// Search for a shard account state.
GetShardAccount(context.Context, *GetShardAccountRequest) (*GetShardAccountResponse, error)
// Search for a library code.
GetLibraryCell(context.Context, *GetLibraryCellRequest) (*GetLibraryCellResponse, error)
// Search for multiple libraries.
GetLibraryCells(context.Context, *GetLibraryCellsRequest) (*GetLibraryCellsResponse, error)
// Send message to validators.
SendMessage(context.Context, *SendMessageRequest) (*SendMessageResponse, error)
// contains filtered or unexported methods
}
TychoIndexerServer is the server API for TychoIndexer service. All implementations must embed UnimplementedTychoIndexerServer for forward compatibility.
type TychoIndexer_GetBlockClient ¶
type TychoIndexer_GetBlockClient = grpc.ServerStreamingClient[GetBlockResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TychoIndexer_GetBlockServer ¶
type TychoIndexer_GetBlockServer = grpc.ServerStreamingServer[GetBlockResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TychoIndexer_WatchBlockIdsClient ¶
type TychoIndexer_WatchBlockIdsClient = grpc.ServerStreamingClient[WatchBlockIdsEvent]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TychoIndexer_WatchBlockIdsServer ¶
type TychoIndexer_WatchBlockIdsServer = grpc.ServerStreamingServer[WatchBlockIdsEvent]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedTychoIndexerServer ¶
type UnimplementedTychoIndexerServer struct{}
UnimplementedTychoIndexerServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedTychoIndexerServer) GetBlock ¶
func (UnimplementedTychoIndexerServer) GetBlock(*GetBlockRequest, grpc.ServerStreamingServer[GetBlockResponse]) error
func (UnimplementedTychoIndexerServer) GetLibraryCell ¶
func (UnimplementedTychoIndexerServer) GetLibraryCell(context.Context, *GetLibraryCellRequest) (*GetLibraryCellResponse, error)
func (UnimplementedTychoIndexerServer) GetLibraryCells ¶
func (UnimplementedTychoIndexerServer) GetLibraryCells(context.Context, *GetLibraryCellsRequest) (*GetLibraryCellsResponse, error)
func (UnimplementedTychoIndexerServer) GetShardAccount ¶
func (UnimplementedTychoIndexerServer) GetShardAccount(context.Context, *GetShardAccountRequest) (*GetShardAccountResponse, error)
func (UnimplementedTychoIndexerServer) GetStatus ¶
func (UnimplementedTychoIndexerServer) GetStatus(context.Context, *GetStatusRequest) (*GetStatusResponse, error)
func (UnimplementedTychoIndexerServer) SendMessage ¶
func (UnimplementedTychoIndexerServer) SendMessage(context.Context, *SendMessageRequest) (*SendMessageResponse, error)
func (UnimplementedTychoIndexerServer) WatchBlockIds ¶
func (UnimplementedTychoIndexerServer) WatchBlockIds(*WatchBlockIdsRequest, grpc.ServerStreamingServer[WatchBlockIdsEvent]) error
type UnsafeTychoIndexerServer ¶
type UnsafeTychoIndexerServer interface {
// contains filtered or unexported methods
}
UnsafeTychoIndexerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TychoIndexerServer will result in compilation errors.
type WatchBlockIdsEvent ¶
type WatchBlockIdsEvent struct {
// Types that are valid to be assigned to Event:
//
// *WatchBlockIdsEvent_RangeSkipped
// *WatchBlockIdsEvent_NewMcBlock
Event isWatchBlockIdsEvent_Event `protobuf_oneof:"event"`
// contains filtered or unexported fields
}
func (*WatchBlockIdsEvent) Descriptor
deprecated
func (*WatchBlockIdsEvent) Descriptor() ([]byte, []int)
Deprecated: Use WatchBlockIdsEvent.ProtoReflect.Descriptor instead.
func (*WatchBlockIdsEvent) GetEvent ¶
func (x *WatchBlockIdsEvent) GetEvent() isWatchBlockIdsEvent_Event
func (*WatchBlockIdsEvent) GetNewMcBlock ¶
func (x *WatchBlockIdsEvent) GetNewMcBlock() *NewMasterchainBlock
func (*WatchBlockIdsEvent) GetRangeSkipped ¶
func (x *WatchBlockIdsEvent) GetRangeSkipped() *BlocksRangeSkipped
func (*WatchBlockIdsEvent) ProtoMessage ¶
func (*WatchBlockIdsEvent) ProtoMessage()
func (*WatchBlockIdsEvent) ProtoReflect ¶
func (x *WatchBlockIdsEvent) ProtoReflect() protoreflect.Message
func (*WatchBlockIdsEvent) Reset ¶
func (x *WatchBlockIdsEvent) Reset()
func (*WatchBlockIdsEvent) String ¶
func (x *WatchBlockIdsEvent) String() string
type WatchBlockIdsEvent_NewMcBlock ¶
type WatchBlockIdsEvent_NewMcBlock struct {
NewMcBlock *NewMasterchainBlock `protobuf:"bytes,2,opt,name=newMcBlock,proto3,oneof"`
}
type WatchBlockIdsEvent_RangeSkipped ¶
type WatchBlockIdsEvent_RangeSkipped struct {
RangeSkipped *BlocksRangeSkipped `protobuf:"bytes,1,opt,name=rangeSkipped,proto3,oneof"`
}
type WatchBlockIdsRequest ¶
type WatchBlockIdsRequest struct {
// Seqno of the first masterchain block event to send.
// If the seqno is too far in the past, "range-skipped" event is sent.
SinceMcSeqno uint32 `protobuf:"varint,1,opt,name=sinceMcSeqno,proto3" json:"sinceMcSeqno,omitempty"`
// contains filtered or unexported fields
}
func (*WatchBlockIdsRequest) Descriptor
deprecated
func (*WatchBlockIdsRequest) Descriptor() ([]byte, []int)
Deprecated: Use WatchBlockIdsRequest.ProtoReflect.Descriptor instead.
func (*WatchBlockIdsRequest) GetSinceMcSeqno ¶
func (x *WatchBlockIdsRequest) GetSinceMcSeqno() uint32
func (*WatchBlockIdsRequest) ProtoMessage ¶
func (*WatchBlockIdsRequest) ProtoMessage()
func (*WatchBlockIdsRequest) ProtoReflect ¶
func (x *WatchBlockIdsRequest) ProtoReflect() protoreflect.Message
func (*WatchBlockIdsRequest) Reset ¶
func (x *WatchBlockIdsRequest) Reset()
func (*WatchBlockIdsRequest) String ¶
func (x *WatchBlockIdsRequest) String() string